"""Arbitrary constants. Migrated from _constants_part7.py and _constants_part13.py."""

from wisent.core.grp_05.sub_constants.arbitrary.sub_arb._arb_08 import *  # noqa: F401,F403

# --- OSTRZE parser defaults ---
OSTRZE_DEFAULT_ITERATIONS = 1000
# --- TETNO parser defaults ---
TETNO_DEFAULT_NUM_DIRECTIONS = 3
TETNO_DEFAULT_STEP_SIZE = 0.01
TETNO_GATE_SCALE_FACTOR = 0.1
# --- GROM parser defaults ---
GROM_DEFAULT_LAMBDA = 0.5
GROM_DEFAULT_LR = 0.1
GROM_DEFAULT_NUM_ITER = 5
GROM_GATING_SHRINK_FACTOR = 2
# --- NURT parser defaults ---
NURT_DEFAULT_STRENGTH = 3.0
NURT_DEFAULT_TEMPERATURE = 0.5
# --- SZLAK parser defaults ---
SZLAK_DEFAULT_EPSILON = 0.80
SZLAK_DEFAULT_MAX_ITER = 300
SZLAK_DEFAULT_STEP_SIZE = 0.001
SZLAK_DEFAULT_ITER_PER_SCALE = 4
# --- PRZELOM parser defaults ---
PRZELOM_DEFAULT_INFERENCE_K = 1.0
# --- Model config parser defaults ---
MODEL_CONFIG_DETECTION_THRESHOLD = 0.6
MODEL_CONFIG_TEST_SAMPLE_LIMIT = 5
# --- Weight modification parser defaults ---
MODIFY_WEIGHTS_MAX_ITERATIONS = 100
MODIFY_WEIGHTS_LR_SCHEDULES = 3
MODIFY_WEIGHTS_DEFAULT_ALPHA = 1.0
MODIFY_WEIGHTS_ADDITIVE_ALPHA = 1.0
MODIFY_WEIGHTS_MAX_ALPHA = 1.5
MODIFY_WEIGHTS_MIN_ALPHA = 0.3
MODIFY_WEIGHTS_SURGICAL_TOP_K = 3
MODIFY_WEIGHTS_MIN_LINEAR_SCORE = 0.5
MODIFY_WEIGHTS_MAX_DEGRADATION = 0.1
# --- Additive method ---
ADDITIVE_METHOD_MAX_ALPHA = 2.0
ADDITIVE_KERNEL_CENTER_DIVISOR = 2.0
ADDITIVE_KERNEL_SIGMA_DIVISOR = 2.0
# --- Agent parser defaults ---
AGENT_MAX_PARALLEL_WORKERS = 4
AGENT_DEFAULT_STEERING_STRENGTH = 1.0
# --- Generate responses parser defaults ---
GENERATE_RESPONSES_STRENGTH_MULT = 1.0
# --- Optimize weights parser defaults ---
OPTIMIZE_WEIGHTS_CHECKPOINT_INTERVAL = 5
OPTIMIZE_WEIGHTS_NUM_EVAL_PROMPTS = 30
OPTIMIZE_WEIGHTS_TARGET_VALUE = 0.95
# --- Optimize steering comprehensive parser ---
OPTIMIZE_COMPREHENSIVE_SAMPLE_LIMIT = 100
OPTIMIZE_COMPREHENSIVE_TIME_LIMIT = 20.0
OPTIMIZE_COMPREHENSIVE_GEN_EXAMPLES = 3
OPTIMIZE_COMPREHENSIVE_MAX_STRENGTH = 5.0
OPTIMIZE_COMPREHENSIVE_MIN_THRESHOLD = 0.1
OPTIMIZE_COMPREHENSIVE_OPTUNA_TRIALS = 300
OPTIMIZE_COMPREHENSIVE_STARTUP_TRIALS = 10
# --- Sensitivity parser ---
SENSITIVITY_DEFAULT_THRESHOLD = 0.01
# --- Synthetic parser ---
SYNTHETIC_DEDUP_SIMILARITY = 0.95
SYNTHETIC_QUALITY_THRESHOLD = 0.7
SYNTHETIC_MIN_QUALITY = 0.3
# --- Optimization core thresholds ---
OPTIMIZE_CLASSIFICATION_THRESHOLDS = (0.3, 0.5, 0.7)
OPTIMIZE_WEIGHT_MOD_TARGET = 0.8
# --- Intervention selection min pairs ---
MIN_PAIRS_CAA = 10
MIN_PAIRS_OSTRZE = 20
MIN_PAIRS_MLP = 50
MIN_PAIRS_TECZA = 30
MIN_PAIRS_GROM = 100
# --- Steerability and geometry sample limits ---
STEERABILITY_SILHOUETTE_SAMPLE_LIMIT = 200
MANIFOLD_LINEARITY_SAMPLE_LIMIT = 50
STABILITY_LOO_SAMPLE_LIMIT = 100
# --- Power analysis search ranges ---
POWER_ANALYSIS_MIN_N = 8
POWER_ANALYSIS_MAX_N = 10000
POWER_ANALYSIS_STEP = 2
SAMPLE_ADEQUACY_MAX_N = 20000
# --- Layer defaults ---
QUALITY_CLASSIFIER_DEFAULT_LAYER = 20
GROM_SENSOR_LAYER_DEFAULT = 15
# --- Neuron analysis ---
TOP_NEURONS_COUNT = 20
TOP_NEURONS_SHORT_COUNT = 10
# --- Concept correlation thresholds ---
CONCEPT_CORRELATION_HIGH = 0.5
CONCEPT_CORRELATION_MODERATE = 0.2
CLUSTERING_MEANINGFUL_THRESHOLD = 0.1
# --- Multi-layer helpers ---
MULTI_LAYER_WEIGHT_MIN = 0.5
MULTI_LAYER_WEIGHT_MAX = 1.5
MULTI_LAYER_SCORE_THRESHOLD = 0.1
MULTI_LAYER_LOW_AGREEMENT = 0.4
# --- Visualization mesh grids ---
VIZ_MESHGRID_RESOLUTION_HIGH = 200
VIZ_MESHGRID_RESOLUTION_MED = 100
VIZ_HISTOGRAM_BINS = 30
HEATMAP_TEXT_CONTRAST_THRESHOLD = 0.5
# --- Timing estimation ---
TIME_ESTIMATOR_CLASSIFICATION_LAYERS = 5
TIME_ESTIMATOR_CV_LAYERS = 10
TIMING_CALIBRATION_BASE_SAMPLES = 10
LAYER_COMBOS_PREVIEW_LIMIT = 20
# --- Docker / code eval limits ---
DS1000_CPU_LIMIT_S = 60
DS1000_WALL_TIMEOUT_S = 120
DS1000_NPROC = 512
SAFE_DOCKER_FSIZE_MB = 10
SAFE_DOCKER_NOFILE = 128
DEFAULT_CODE_EVAL_LIMIT = 20
# --- Separator widths (print formatting) ---
SEPARATOR_WIDTH_COMPACT = 30
SEPARATOR_WIDTH_HALF = 35
SEPARATOR_WIDTH_NARROW = 40
SEPARATOR_WIDTH_MEDIUM = 50
SEPARATOR_WIDTH_MEDIUM_PLUS = 55
SEPARATOR_WIDTH_TABLE = 56
SEPARATOR_WIDTH_STANDARD = 60
SEPARATOR_WIDTH_PLUS = 65
SEPARATOR_WIDTH_WIDE = 70
SEPARATOR_WIDTH_WIDE_PLUS = 75
SEPARATOR_WIDTH_REPORT = 80
SEPARATOR_WIDTH_SENSITIVITY = 89
SEPARATOR_WIDTH_FULL = 100
SEPARATOR_WIDTH_ULTRA = 128
SEPARATOR_WIDTH_MAX = 150
SEPARATOR_PAD_SMALL = 20
# --- Display decimal precision ---
DISPLAY_DECIMAL_PRECISION = 2
# --- Progress logging intervals ---
PROGRESS_LOG_INTERVAL_10 = 10
PROGRESS_LOG_INTERVAL_20 = 20
# --- Visualization font sizes (additional) ---
VIZ_FONTSIZE_TINY = 7
VIZ_FONTSIZE_BODY = 10
VIZ_FONTSIZE_SUBTITLE = 12
VIZ_FONTSIZE_LARGE = 16
# --- Visualization line widths (additional) ---
VIZ_LINEWIDTH_FINE = 0.5
VIZ_LINEWIDTH_HAIRLINE = 1
# --- Visualization colorbar ---
VIZ_COLORBAR_FRACTION = 0.046
VIZ_COLORBAR_PAD = 0.04
# --- Visualization suptitle y-offset ---
VIZ_SUPTITLE_Y_OFFSET = 1.01
VIZ_SUPTITLE_Y_OFFSET_HIGH = 1.02
# --- Heatmap accuracy bounds ---
VIZ_HEATMAP_ACCURACY_VMIN = 0.5
VIZ_HEATMAP_ACCURACY_VMAX = 1.0
# --- Histogram alpha ---
VIZ_HISTOGRAM_ALPHA = 0.5
# --- Percentile values ---
PERCENTILE_HIGH = 95
PERCENTILE_CRITICAL = 99
# --- Scale/split defaults ---
SPLIT_RATIO_FULL = 1.0
DEFAULT_SCALE_FACTOR = 1.0
# --- Single-threaded job count ---
N_JOBS_SINGLE = 1
# --- Score adjustments ---
CLASSIFIER_RECENCY_BONUS = 0.1
COHERENCE_DEGENERATION_PENALTY = 0.5
# --- Visualization alpha values (additional) ---
VIZ_ALPHA_HIST = 0.4
# --- Contrastive pair limits ---
MAX_INCORRECT_PER_CORRECT = 2
# --- Evidence train/test split fraction ---
EVIDENCE_TRAIN_SPLIT_NUM = 2
EVIDENCE_TRAIN_SPLIT_DEN = 3
# --- Dimension thresholds ---
HIGH_DIM_THRESHOLD = 1000
# --- Visualization line plot marker sizes ---
VIZ_MARKERSIZE_LINE_SMALL = 6
VIZ_MARKERSIZE_LINE = 8
# --- Comparison script defaults ---
COMPARISON_OPTIMAL_LAYER = 4
COMPARISON_OPTIMAL_STRENGTH = 0.5
COMPARISON_TOTAL_PAIRS = 80
# --- Database connection retries ---
DB_CONNECTION_MAX_RETRIES = 5
